From b6c8a0701744fb49b478ae3d85e0e11e5efd205e Mon Sep 17 00:00:00 2001
From: Alon Bar-Lev <alon.barlev@gmail.com>
Date: Sun, 7 Oct 2018 19:29:22 +0300
Subject: [PATCH] fltk-config: support SYSROOT

When cross-compiling a library, the compiler flags should be relative to the
host root and not build root.

The SYSROOT environment variable is a known convention for defining the
location of the host root within the build root.

Any absolute path which does not contain the SYSROOT should be prefixed with
the SYSROOT.

Signed-off-by: Alon Bar-Lev <alon.barlev@gmail.com>
---
 fltk-config.in | 17 +++++++++++++++++
 1 file changed, 17 insertions(+)

diff --git a/fltk-config.in b/fltk-config.in
index 5161efaa6..5ff44120e 100644
--- a/fltk-config.in
+++ b/fltk-config.in
@@ -35,6 +35,23 @@ includedir=@includedir@
 libdir=@libdir@
 srcdir=@srcdir@
 
+inject_sysroot() {
+	local in="$1"
+	local out="${in}"
+
+	if [ -n "${SYSROOT}" ]; then
+		case "${in}" in
+			${SYSROOT}/*);;
+			/*) out="${SYSROOT}${in}";;
+		esac
+	fi
+	echo "${out}"
+}
+
+for v in prefix exec_prefix includedir libdir; do
+	eval ${v}="\$(inject_sysroot "\${${v}}")"
+done
+
 # BINARY_DIR - used only for CMake builds in local (binary) directory
 BINARY_DIR=@BINARY_DIR@
 
-- 
2.18.0

